package Ukigumo::Common;
use strict;
use warnings;
use 5.008001;
our $VERSION = '0.09';

1;
__END__

=encoding utf8

=head1 NAME

Ukigumo::Common - Common things between Ukigumo::Client/Ukigumo::Server

=head1 SYNOPSIS

  use Ukigumo::Common;

=head1 DESCRIPTION

Ukigumo::Common is a dummy package. This distribution contains a common things for client/server.

=head1 POLICY

This distribution should on perl 5.8.

=head1 AUTHOR

Tokuhiro Matsuno E<lt>tokuhirom AAJKLFJEF@ GMAIL COME<gt>

=head1 SEE ALSO

L<Ukigumo::Client>/L<Ukigumo::Server>

=head1 LICENSE

Copyright (C) Tokuhiro Matsuno

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

=cut
